import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:equatable/equatable.dart';

class PromotionGetCategories
    implements UseCase<dynamic, PromotionGetCategoriesParams> {
  final PromotionRepository repository;

  PromotionGetCategories(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      PromotionGetCategoriesParams params) async {
    return await repository.getCategories(
      publisherName: params.publisherName,
      start: params.start,
      limit: params.limit,
    );
  }
}

class PromotionGetCategoriesParams extends Equatable {
  final String publisherName;
  final int start;
  final int limit;

  PromotionGetCategoriesParams({
    this.publisherName,
    this.start,
    this.limit,
  });

  @override
  List<Object> get props => [
        publisherName,
        start,
        limit,
      ];
}
