import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/store_repository.dart';
import 'package:equatable/equatable.dart';

class StoreGetStores implements UseCase<dynamic, StoreGetStoresParams> {
  final StoreRepository repository;

  StoreGetStores(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(StoreGetStoresParams params) async {
    return await repository.getStores(
      start: params.start,
      limit: params.limit,
      promotionToken: params.promotionToken,
      retailerTokens: params.retailerTokens,
      zipcode: params.zipcode,
      latitude: params.latitude,
      longitude: params.longitude,
      radius: params.radius,
      publisherName: params.publisherName,
    );
  }
}

class StoreGetStoresParams extends Equatable {
  final int start;
  final int limit;
  final String promotionToken;
  final List<String> retailerTokens;
  final String zipcode;
  final String latitude;
  final String longitude;
  final String radius;
  final String publisherName;

  StoreGetStoresParams({
    this.start,
    this.limit,
    this.promotionToken,
    this.retailerTokens,
    this.zipcode,
    this.latitude,
    this.longitude,
    this.radius,
    this.publisherName,
  });

  @override
  List<Object> get props => [
        start,
        limit,
        promotionToken,
        retailerTokens,
        zipcode,
        latitude,
        longitude,
        radius,
        publisherName,
      ];
}
